@@ -74,8 +74,8 @@ default_sso_settings = {
     "HTML_RESET_PASSWORD_SUBJECT": "Reset password",
     "HTML_DEFAULT_FROM_EMAIL": EMAIL_USERNAME,
     "HTML_CONFIRMATION_SUBJECT": "Confirm account",
-    "HTML_EMAIL_RESET_TEMPLATE": None,
-    "HTML_EMAIL_CONFIRM_TEMPLATE": None,
+    "HTML_EMAIL_RESET_TEMPLATE": '',
+    "HTML_EMAIL_CONFIRM_TEMPLATE": '',
     "SERIALIZERS": ObjDict({
         "USER_RETURN_SERIALIZER": "drf_auth_service.users.serializers.ReturnUserBaseSerializer",
         "USER_SERIALIZER": "drf_auth_service.users.serializers.UserBaseSerializer",
