@@ -1,3 +1,5 @@
+from urllib.parse import urlparse
+
 from drf_yasg import openapi
 from rest_framework import mixins
 from rest_framework.decorators import action
@@ -8,6 +10,7 @@ from rest_framework_simplejwt.settings import api_settings
 
 from drf_auth_service.authentication.serializers import ReturnJWTTokensSerializer, ReturnSuccessSerializer
 from drf_auth_service.common.backends import BaseBackend
+from drf_auth_service.common.helpers import set_cookies
 from drf_auth_service.common.managers import BaseManager
 from drf_auth_service.common.mixins import GenericEBSViewSet
 from drf_auth_service.models import ActivationCode, UserBlock
@@ -37,7 +40,8 @@ class UserViewSet(
         serializer.is_valid(raise_exception=True)
         user = self.get_user_by_username(request.service, serializer.validated_data['username'])
         ActivationCode.make_user_active(user)
-        return Response(BaseBackend.get_jwt_response(user))
+
+        return set_cookies(Response(BaseBackend.get_jwt_response(user)))
 
     @action(detail=False, methods=['POST'], url_path='resend-confirmation',
             serializer_class=settings.SERIALIZERS.RETURN_SUCCESS_SERIALIZER,
